#
# spec file for package vlc
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Dominique Leuenberger, Amsterdam, The Netherlands
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libvlc 5
%define libvlccore 7
%define conflicts vlc-beta

# Currently no ncurses support. Will have to find the right trick for integrating curses (which is a curse)
%define with_ncurses 0

# Fluidsynth plugin is known to cause strange crashes here and there - disable it for now (2014-10-07, DimStar)
%bcond_with fluidsynth

%ifarch %arm
%bcond_without opengles
%else
%bcond_with opengles
%endif

Summary:        Video Lan Client multimedia player
License:        GPL-2.0+ and LGPL-2.1+
Group:          Productivity/Multimedia/Video/Players	
Name:           vlc
Version:        2.1.5
Release:        239.2
Url:            http://www.videolan.org/
Source:         http://download.videolan.org/%{name}/%{version}/%{name}-%{version}.tar.xz
# Add vlc.changes as source, so we can reproducibly extract the date from it during build
Source1:        %{name}.changes
# PATCH-FIX-OPENSUSE vlc-2.1.5-fix-skins2-default-skin-creation.patch -- see description in patch header 
Patch1:         vlc-2.1.5-fix-skins2-default-skin-creation.patch
# PATCH-FIX-UPSTREAM vlc-CVE-2014-9625.patch boo#914268 CVE-2014-9625 dimstar@opensuse.org -- Fix various buffer overflows and null ptr deref
Patch2:         vlc-CVE-2014-9625.patch
Patch3:         0001-no-return-in-non-void.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  Mesa-devel
BuildRequires:  aalib-devel
BuildRequires:  fdupes
BuildRequires:  pkgconfig(alsa) >= 1.0.24
BuildRequires:  pkgconfig(avahi-client) >= 0.6
BuildRequires:  pkgconfig(flac)
%if %{with fluidsynth}
BuildRequires:  pkgconfig(fluidsynth) >= 1.1.2
%endif
%if 0%{?suse_version} >= 1220
BuildRequires:  pkgconfig(freerdp) >= 1.0.1
%endif
BuildRequires:  gdk-pixbuf-devel
BuildRequires:  gettext-devel
BuildRequires:  git
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(gnome-vfs-2.0)
%if 0%{?suse_version} >= 1220
BuildRequires:  pkgconfig(gnutls) >= 3.0.20
%endif
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(sdl) >= 1.2.10
%if 0%{?suse_version} >= 1140
BuildRequires:  pkgconfig(SDL_image) >= 1.2.10
%endif
BuildRequires:  pkgconfig(caca) >= 0.99.beta14
BuildRequires:  pkgconfig(libass) >= 0.9.8
BuildRequires:  pkgconfig(libavc1394) >= 0.5.3
BuildRequires:  pkgconfig(libbluray) >= 0.2.1
BuildRequires:  pkgconfig(libcddb) >= 0.9.5
%if 0%{?suse_version} != 1315
BuildRequires:  libkde4-devel
%endif
%if 0%{?suse_version} >= 1230 && 0%{?suse_version} != 1315
BuildRequires:  pkgconfig(libchromaprint) >= 0.6.0
%endif
%if 0%{?suse_version} >= 1140
BuildRequires:  pkgconfig(libdc1394-2) >= 2.1.0
%endif
BuildRequires:  libgcrypt-devel
BuildRequires:  libmatroska-devel
BuildRequires:  pkgconfig(dvdnav)
BuildRequires:  pkgconfig(dvdread)
BuildRequires:  pkgconfig(jack) >= 1.9.7
BuildRequires:  pkgconfig(kate) >= 0.3.0
BuildRequires:  pkgconfig(libdvbpsi) < 1.0
BuildRequires:  pkgconfig(libidn)
BuildRequires:  pkgconfig(libmodplug) > 0.8.8
%if 0%{?suse_version} > 1230 && 0%{?suse_version} != 1315
BuildRequires:  libmlt6-modules
%endif
%if 0%{?suse_version} >= 1140
BuildRequires:  pkgconfig(libmtp) >= 1.0.0
%endif
BuildRequires:  libproxy-devel
BuildRequires:  libtool
BuildRequires:  libv4l-devel
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libraw1394) >= 2.0.1
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.9.0
BuildRequires:  pkgconfig(libssh2)
BuildRequires:  pkgconfig(libudev) >= 142
BuildRequires:  pkgconfig(libupnp)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-x11)
BuildRequires:  pkgconfig(ogg) >= 1.0
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(shout) >= 2.1
BuildRequires:  pkgconfig(smbclient)
BuildRequires:  pkgconfig(taglib) >= 1.6.1
BuildRequires:  pkgconfig(theoradec) >= 1.0
BuildRequires:  pkgconfig(theoraenc)
%if 0%{?suse_version} >= 1310
BuildRequires:  pkgconfig(libvncclient) >= 0.9.9
%endif
BuildRequires:  lirc-devel
BuildRequires:  pkgconfig(libxml-2.0) >= 2.5
BuildRequires:  pkgconfig(live555)
BuildRequires:  pkgconfig(lua) >= 5.1
BuildRequires:  pkgconfig(vorbis) >= 1.1
BuildRequires:  pkgconfig(vorbisenc) >= 1.1
%if 0%{?suse_version} >= 1140 && 0%{?suse_version} != 1315
BuildRequires:  pkgconfig(opencv) > 2.0
%endif
BuildRequires:  pcre-devel
%if 0%{?suse_version} >= 1220
BuildRequires:  pkgconfig(libprojectM) >= 2.0.0
%endif
BuildRequires:  pulseaudio-devel
BuildRequires:  slang-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(schroedinger-1.0) >= 1.0.10
BuildRequires:  pkgconfig(speex) >= 1.0.5
BuildRequires:  pkgconfig(speexdsp)
%if 0%{?suse_version} != 1315
BuildRequires:  vcdimager-devel
BuildRequires:  pkgconfig(libcdio) >= 0.78.2
BuildRequires:  pkgconfig(libiso9660) >= 0.72
BuildRequires:  pkgconfig(libvcdinfo) >= 0.7.22
%endif
%if 0%{?suse_version} >= 1140
BuildRequires:  pkgconfig(xcb) >= 1.6
BuildRequires:  pkgconfig(xcb-composite)
BuildRequires:  pkgconfig(xcb-keysyms) >= 0.3.4
BuildRequires:  pkgconfig(xcb-randr) >= 1.3
BuildRequires:  pkgconfig(xcb-shm)
BuildRequires:  pkgconfig(xcb-xv) >= 1.1.90.1
BuildRequires:  pkgconfig(xproto)
%endif
BuildRequires:  xosd-devel
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtGui) >= 4.6.0
BuildRequires:  pkgconfig(dbus-1) >= 1.0.0
BuildRequires:  pkgconfig(dirac) >= 0.10.0
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libgme)
BuildRequires:  pkgconfig(libpulse) >= 0.9.22
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(zvbi-0.2) >= 0.2.28
# This is intentionally done the pkgconfig way: 3rd party repos might have alternative implementations
# and can favor one over the other.
%if 0%{?suse_version} >= 1310 || 0%{?BUILD_ORIG}
BuildRequires:  pkgconfig(libswscale)
%endif
# BuildRequires that are not actively used for VLC, but for the build itself to work smoothly
BuildRequires:  findutils
BuildRequires:  update-desktop-files
BuildRequires:  xz
# ncurses are not ready so far
%if %{?with_ncurses}
BuildRequires:  ncurses-devel
%endif
# Those are dependencies which are NOT provided in openSUSE, mostly for legal reasons.
%if 0%{?BUILD_ORIG}
BuildRequires:  faad2-devel
BuildRequires:  liba52-devel
BuildRequires:  libfaac-devel
BuildRequires:  libmad-devel
BuildRequires:  libxvidcore-devel
BuildRequires:  pkgconfig(libavcodec) >= 53.34.0
BuildRequires:  pkgconfig(libavformat) >= 53.21.0
BuildRequires:  pkgconfig(libavutil) >= 51.22.0
BuildRequires:  pkgconfig(libdca) >= 0.0.5
BuildRequires:  pkgconfig(libmpeg2) > 0.3.2
BuildRequires:  pkgconfig(libpostproc)
BuildRequires:  pkgconfig(twolame)
BuildRequires:  pkgconfig(vdpau)
BuildRequires:  pkgconfig(x264) >= 0.86
%endif

Requires:       %{name}-noX = %{version}-%{release}
Requires:       %{name}-qt = %{version}-%{release}
Conflicts:      %{conflicts}

%description
VLC media player is a highly portable multimedia player for various 
audio and video formats (MPEG-1, MPEG-2, MPEG-4, DivX, mp3, ogg, ...) 
as well as DVDs, VCDs, and various streaming protocols. 
It can also be used as a server to stream in unicast or multicast 
in IPv4 or IPv6 on a high-bandwidth network.

%package devel
Summary:        VLC Development system
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Those development headers are required if you plan on coding against VLC

%package -n libvlc%{libvlc}
Summary:        Shared library libvlc
License:        LGPL-2.1+
Group:          System/Libraries

%description -n libvlc%{libvlc}
Shared library libvlc. To be installed by system dependencies

%package -n libvlccore%{libvlccore}
Summary:        Shared library libvlc
License:        LGPL-2.1+
Group:          System/Libraries

%description -n libvlccore%{libvlccore}
Shared library libvlc. To be installed by system dependencies

%package noX
Summary:        VLC: VideoLAN Client - without X dependencies
License:        GPL-2.0+ and LGPL-2.1+
Group:          Productivity/Multimedia/Video/Players
Requires:       libvlc%{libvlc} = %{version}-%{release}
Requires:       libvlccore%{libvlccore} = %{version}-%{release}
Conflicts:      %{conflicts}-noX
Recommends:     libdvdcss
# pulseaudio subpackage merge
Supplements:    packageand(%{name}-noX:pulseaudio)
Provides:       vlc-aout-pulse = %{version}
Obsoletes:      vlc-aout-pulse < %{version}
# lang subpackage
Recommends:     vlc-noX-lang

%description noX
This Package of VLC contains the bare requirements you need to install.
Here is no graphical User Interface included, thus it's also perfectly
suitable for server installations (Streaming Server for example)

Should you decide to install the GUI modules, %{name}-noX will stay
installed as a dependency.

%lang_package -n vlc-noX

%if 0%{?BUILD_ORIG}
%package codecs
Summary:        VLC: VideoLAN Client - Codec extension
License:        GPL-2.0+ and LGPL-2.1+
Group:          Productivity/Multimedia/Video/Players
Requires:       vlc-noX = %{version}
Supplements:    vlc-noX

%description codecs
This Package enhances the functionality of the VLC VideoLAN Client with
Codecs that are not available in a stock openSUSE distribution.
%endif

%package qt
Summary:        VLC: VideoLAN Client - Qt interface
License:        GPL-2.0+ and LGPL-2.1+
Group:          Productivity/Multimedia/Video/Players
Supplements:    packageand(%{name}-noX:libqt4)
Requires:       %{name}-noX = %{version}-%{release}
Recommends:     %{name}
Conflicts:      %{conflicts}-qt

%description qt
The all new Qt interface for the VLC VideoLAN Client.

%package gnome
Summary:        VLC: VideoLAN Client - Gnome Access Modules
License:        GPL-2.0+ and LGPL-2.1+
Group:          Productivity/Multimedia/Video/Players
Supplements:    packageand(%{name}-noX:gnome-vfs2)
Requires:       %{name}-noX = %{version}-%{release}
Conflicts:      %{conflicts}-gnome

%description gnome
In order to integrate flawless into GNOME, there are some access modules
for gnome-vfs2.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
# We do not rely on contrib but make use of system libraries
rm -rf contrib
# fix builddate info
# Remove build time references so build-compare can do its work
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{S:1} '+%%H:%%M')
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{S:1} '+%%b %%e %%Y')
sed -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" -i modules/gui/qt4/dialogs/help.cpp src/config/help.c
sed -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -i modules/gui/qt4/dialogs/help.cpp src/config/help.c

%build 
pkg-config --exists smbclient && smbclient=$(pkg-config --cflags smbclient)
%ifarch %{ix86}
export CFLAGS="%{optflags} -L%{_libdir}/live -msse -Wno-return-type $smbclient"
export CXXFLAGS="%{optflags} -L%{_libdir}/live -msse -Wno-return-type $smbclient"
%else
%ifarch x86_64
export CFLAGS="%{optflags} -L%{_libdir}/live -msse2 -Wno-return-type $smbclient"
export CXXFLAGS="%{optflags} -L%{_libdir}/live -msse2 -Wno-return-type $smbclient"
%else
export CFLAGS="%{optflags} -L%{_libdir}/live -Wno-return-type $smbclient"
export CXXFLAGS="%{optflags} -L%{_libdir}/live -Wno-return-type $smbclient"
%endif
%endif

%configure \
   --disable-static                     \
   --disable-dependency-tracking        \
   --enable-aa                          \
   --enable-alsa                        \
   --enable-dvbpsi                      \
   --enable-dvdnav                      \
   --enable-dvdread                     \
   --enable-fast-install                \
   --enable-flac                        \
   --enable-freetype                    \
   --enable-fribidi                     \
   --enable-glx                         \
   --enable-gme                         \
   --enable-gnomevfs                    \
%if 0%{?suse_version} >= 1220
   --enable-gnutls                      \
%endif
   --enable-httpd                       \
   --enable-jack                        \
   --enable-kate                        \
   --enable-libass                      \
   --enable-libcddb                     \
   --enable-lirc                        \
   --enable-live555						\
%if 0%{?suse_version} >= 1310 || 0%{?BUILD_ORIG}
   --enable-swscale                     \
%else
   --disable-swscale                    \
%endif
%if 0%{?BUILD_ORIG}
   --enable-libmpeg2                    \
   --enable-mad                         \
   --enable-avcodec                     \
   --enable-postproc                    \
   --enable-faad                        \
   --enable-a52                         \
   --enable-dca                         \
%else
   --disable-libmpeg2                   \
   --disable-mad                        \
   --disable-avcodec                    \
   --disable-postproc                   \
   --disable-faad                       \
   --disable-a52                        \
   --disable-dca                        \
%endif
   --enable-lua                         \
   --enable-mkv                         \
   --enable-mod                         \
%if %{?with_ncurses}
   --enable-ncurses                     \
%else
    --disable-ncurses                   \
%endif
   --enable-ogg                         \
   --enable-optimizations               \
   --enable-opus                        \
   --disable-oss                        \
   --enable-png                         \
   --enable-pulse                       \
   --enable-realrtsp                    \
   --enable-smbclient                   \
   --enable-sout                        \
   --enable-speex                       \
   --enable-taglib                      \
   --enable-theora                      \
   --enable-v4l2                        \
%if 0%{?suse_version} != 1315
   --enable-vcd                         \
   --enable-vcdx                        \
%endif
   --enable-vorbis                      \
   --enable-waveout                     \
%if 0%{?suse_version} >= 1140
   --enable-xcb                         \
%else
   --disable-xcb                        \
%endif
%if %{with opengles}
  --enable-gles2                        \
  --enable-egl                        	\
%endif
  --enable-xvideo                       \
  --with-default-font=/usr/share/fonts/truetype/FreeSerifBold.ttf \
  --with-default-monospace-font=/usr/share/fonts/truetype/FreeMono.ttf
# we don't need no VLC_COMPILE_HOST `hostname -f` in the binary...
sed -i -e 's/^#define VLC_COMPILE_HOST.*/#define VLC_COMPILE_HOST "obs-build"/' config.h
make %{?_smp_mflags} V=1

%install
%make_install
mkdir -p %{buildroot}/%{_datadir}/pixmaps
ln -s %{_datadir}/icons/hicolor/48x48/apps/vlc.png %{buildroot}/%{_datadir}/pixmaps/vlc.png
find %{buildroot} -name *.la -delete
rm %{buildroot}%{_libdir}/vlc/libcompat.a
%suse_update_desktop_file vlc AudioPlayer VideoPlayer Player
%fdupes %{buildroot}%{_datadir}

# clean up some lang issues...
for lang in ach an cgg co ff kmr tet; do
  rm -rf %{buildroot}%{_datadir}/locale/$lang
done
%find_lang vlc

%post
%if 0%{?suse_version} >= 1140
%icon_theme_cache_post
%endif

%postun
%if 0%{?suse_version} >= 1140
%icon_theme_cache_postun
%endif

%post noX
/sbin/ldconfig
%{_libdir}/vlc/vlc-cache-gen -f %{_libdir}/vlc/plugins
%if 0%{?suse_version} >= 1140
%desktop_database_post
%endif

%postun noX
/sbin/ldconfig
%if 0%{?suse_version} >= 1140
%desktop_database_postun
%endif

%post -n libvlc%{libvlc} -p /sbin/ldconfig
%postun -n libvlc%{libvlc} -p /sbin/ldconfig

%post -n libvlccore%{libvlccore} -p /sbin/ldconfig
%postun -n libvlccore%{libvlccore} -p /sbin/ldconfig

%files 
%defattr(-,root,root)
%{_bindir}/svlc
%{_datadir}/icons/hicolor/*/apps/vlc*
%dir %{_datadir}/kde4
%dir %{_datadir}/kde4/apps
%{_datadir}/kde4/apps/solid
%{_libdir}/vlc/plugins/codec/liblibass_plugin.so
%if 0%{?suse_version} >= 1140
%{_libdir}/vlc/plugins/codec/libsdl_image_plugin.so
%endif
%{_libdir}/vlc/plugins//notify/libnotify_plugin.so
%{_libdir}/vlc/plugins//video_filter/libremoteosd_plugin.so
%{_libdir}/vlc/plugins/text_renderer/libfreetype_plugin.so
%if 0%{?suse_version} >= 1140
%{_libdir}/vlc/plugins/video_filter/libpanoramix_plugin.so
%{_libdir}/vlc/plugins/video_output/libxcb_glx_plugin.so
%endif
%if %{with opengles}
%{_libdir}/vlc/plugins/video_output/libegl_plugin.so
%{_libdir}/vlc/plugins/video_output/libgles2_plugin.so
%endif
%{_libdir}/vlc/plugins/video_output/libaa_plugin.so
%if 0%{?suse_version} >= 1220
%{_libdir}/vlc/plugins/visualization/libprojectm_plugin.so
%endif

%files noX-lang -f vlc.lang
%defattr(-,root,root)

%files noX
%defattr(-,root,root)
%doc %{_datadir}/doc/vlc/
%doc NEWS AUTHORS COPYING THANKS README 
%{_bindir}/cvlc
%if %{?with_ncurses}
%{_bindir}/nvlc
%endif
%{_bindir}/rvlc
%{_bindir}/vlc
%{_bindir}/vlc-wrapper
%{_datadir}/applications/vlc.desktop
%{_datadir}/pixmaps/vlc.png
%{_datadir}/vlc/
%{_mandir}/*/vlc*
# Own the file.. but it's an auto-generated file, so ghost it.
%ghost %{_libdir}/vlc/plugins/plugins.dat
%dir %{_libdir}/vlc
%dir %{_libdir}/vlc/lua
%dir %{_libdir}/vlc/lua/extensions
%dir %{_libdir}/vlc/lua/intf
%dir %{_libdir}/vlc/lua/intf/modules
%dir %{_libdir}/vlc/lua/meta
%dir %{_libdir}/vlc/lua/meta/art
%dir %{_libdir}/vlc/lua/meta/fetcher
%dir %{_libdir}/vlc/lua/meta/reader
%dir %{_libdir}/vlc/lua/modules
%dir %{_libdir}/vlc/lua/playlist
%dir %{_libdir}/vlc/lua/sd
%dir %{_libdir}/vlc/plugins
%ifarch ppc ppc64 ppc64le ppc64p7
%dir %{_libdir}/vlc/plugins/altivec
%endif
%dir %{_libdir}/vlc/plugins/access
%dir %{_libdir}/vlc/plugins/access_output
%dir %{_libdir}/vlc/plugins/audio_filter
%dir %{_libdir}/vlc/plugins/audio_mixer
%dir %{_libdir}/vlc/plugins/audio_output
%dir %{_libdir}/vlc/plugins/codec
%dir %{_libdir}/vlc/plugins/control
%dir %{_libdir}/vlc/plugins/demux
%dir %{_libdir}/vlc/plugins/gui
%dir %{_libdir}/vlc/plugins/lua
%dir %{_libdir}/vlc/plugins/meta_engine
%dir %{_libdir}/vlc/plugins/misc
%ifarch %{ix86} x86_64 
%dir %{_libdir}/vlc/plugins/mmx
%endif
%dir %{_libdir}/vlc/plugins/mux
%dir %{_libdir}/vlc/plugins/notify
%dir %{_libdir}/vlc/plugins/packetizer
%dir %{_libdir}/vlc/plugins/services_discovery
%ifarch %{ix86} x86_64
%dir %{_libdir}/vlc/plugins/sse2
%endif
%dir %{_libdir}/vlc/plugins/stream_filter
%dir %{_libdir}/vlc/plugins/stream_out
%dir %{_libdir}/vlc/plugins/text_renderer
%dir %{_libdir}/vlc/plugins/video_chroma
%dir %{_libdir}/vlc/plugins/video_filter
%dir %{_libdir}/vlc/plugins/video_output
%dir %{_libdir}/vlc/plugins/visualization
# Files explicitly listed... so we are in full control of what goes to -noX, -codec or the X-depending pkg.
%{_libdir}/vlc/vlc-cache-gen
%{_libdir}/vlc/lua/extensions/VLSub.luac
%{_libdir}/vlc/lua/intf/cli.luac
%{_libdir}/vlc/lua/intf/dummy.luac
%{_libdir}/vlc/lua/intf/dumpmeta.luac
%{_libdir}/vlc/lua/intf/http.luac
%{_libdir}/vlc/lua/intf/luac.luac
%{_libdir}/vlc/lua/intf/modules/common.luac
%{_libdir}/vlc/lua/intf/modules/host.luac
%{_libdir}/vlc/lua/intf/modules/httprequests.luac
%{_libdir}/vlc/lua/intf/telnet.luac
%{_libdir}/vlc/lua/meta/art/00_musicbrainz.luac
%{_libdir}/vlc/lua/meta/art/01_googleimage.luac
%{_libdir}/vlc/lua/meta/art/02_frenchtv.luac
%{_libdir}/vlc/lua/meta/art/03_lastfm.luac
%{_libdir}/vlc/lua/meta/fetcher/tvrage.luac
%{_libdir}/vlc/lua/meta/reader/filename.luac
%{_libdir}/vlc/lua/modules/dkjson.luac
%{_libdir}/vlc/lua/modules/sandbox.luac
%{_libdir}/vlc/lua/modules/simplexml.luac
%{_libdir}/vlc/lua/playlist/anevia_streams.luac
%{_libdir}/vlc/lua/playlist/anevia_xml.luac
%{_libdir}/vlc/lua/playlist/appletrailers.luac
%{_libdir}/vlc/lua/playlist/bbc_co_uk.luac
%{_libdir}/vlc/lua/playlist/break.luac
%{_libdir}/vlc/lua/playlist/canalplus.luac
%{_libdir}/vlc/lua/playlist/cue.luac
%{_libdir}/vlc/lua/playlist/dailymotion.luac
%{_libdir}/vlc/lua/playlist/extreme.luac
%{_libdir}/vlc/lua/playlist/france2.luac
%{_libdir}/vlc/lua/playlist/googlevideo.luac
%{_libdir}/vlc/lua/playlist/jamendo.luac
%{_libdir}/vlc/lua/playlist/joox.luac
%{_libdir}/vlc/lua/playlist/katsomo.luac
%{_libdir}/vlc/lua/playlist/koreus.luac
%{_libdir}/vlc/lua/playlist/lelombrik.luac
%{_libdir}/vlc/lua/playlist/liveleak.luac
%{_libdir}/vlc/lua/playlist/metacafe.luac
%{_libdir}/vlc/lua/playlist/metachannels.luac
%{_libdir}/vlc/lua/playlist/mpora.luac
%{_libdir}/vlc/lua/playlist/pinkbike.luac
%{_libdir}/vlc/lua/playlist/pluzz.luac
%{_libdir}/vlc/lua/playlist/rockbox_fm_presets.luac
%{_libdir}/vlc/lua/playlist/soundcloud.luac
%{_libdir}/vlc/lua/playlist/vimeo.luac
%{_libdir}/vlc/lua/playlist/youtube.luac
%{_libdir}/vlc/lua/playlist/youtube_homepage.luac
%{_libdir}/vlc/lua/playlist/zapiks.luac
%{_libdir}/vlc/lua/sd/fmc.luac
%{_libdir}/vlc/lua/sd/icecast.luac
%{_libdir}/vlc/lua/sd/jamendo.luac
%{_libdir}/vlc/lua/sd/metachannels.luac
%ifarch ppc ppc64 ppc64le ppc64p7
%{_libdir}/vlc/plugins/altivec/libi420_yuy2_altivec_plugin.so
%endif
%{_libdir}/vlc/plugins/access/libaccess_alsa_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_attachment_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_bd_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_ftp_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_http_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_imem_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_jack_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_mms_plugin.so
%if 0%{?suse_version} >= 1140
%{_libdir}/vlc/plugins/access/libaccess_mtp_plugin.so
%endif
%{_libdir}/vlc/plugins/access/libaccess_rar_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_realrtsp_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_sftp_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_smb_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_tcp_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_udp_plugin.so
%{_libdir}/vlc/plugins/access/libaccess_vdr_plugin.so
%{_libdir}/vlc/plugins/access/libcdda_plugin.so
%if 0%{?suse_version} >= 1140
%{_libdir}/vlc/plugins/access/libdc1394_plugin.so
%endif
%{_libdir}/vlc/plugins/access/libdtv_plugin.so
%{_libdir}/vlc/plugins/access/libdv1394_plugin.so
%{_libdir}/vlc/plugins/access/libdvb_plugin.so
%{_libdir}/vlc/plugins/access/libdvdnav_plugin.so
%{_libdir}/vlc/plugins/access/libdvdread_plugin.so
%{_libdir}/vlc/plugins/access/libfilesystem_plugin.so
%{_libdir}/vlc/plugins/access/libidummy_plugin.so
%{_libdir}/vlc/plugins/access/liblibbluray_plugin.so
%{_libdir}/vlc/plugins/access/liblive555_plugin.so
%{_libdir}/vlc/plugins/access/liblinsys_hdsdi_plugin.so
%{_libdir}/vlc/plugins/access/liblinsys_sdi_plugin.so
%{_libdir}/vlc/plugins/access/libpulsesrc_plugin.so
%if 0%{?suse_version} >= 1220
%{_libdir}/vlc/plugins/access/librdp_plugin.so
%endif
%{_libdir}/vlc/plugins/access/librtp_plugin.so
%{_libdir}/vlc/plugins/access/libsdp_plugin.so
%{_libdir}/vlc/plugins/access/libshm_plugin.so
%{_libdir}/vlc/plugins/access/libstream_filter_rar_plugin.so
%{_libdir}/vlc/plugins/access/libtimecode_plugin.so
%{_libdir}/vlc/plugins/access/libv4l2_plugin.so
%{_libdir}/vlc/plugins/access/libvcd_plugin.so
%if 0%{?suse_version} != 1315
%{_libdir}/vlc/plugins/access/libvcdx_plugin.so
%endif
%if 0%{?suse_version} >= 1310
%{_libdir}/vlc/plugins/access/liblibvnc_plugin.so
%endif
%if 0%{?suse_version} >= 1140
%{_libdir}/vlc/plugins/access/libxcb_screen_plugin.so
%endif
%{_libdir}/vlc/plugins/access/libzip_plugin.so
%{_libdir}/vlc/plugins/access_output/libaccess_output_dummy_plugin.so
%{_libdir}/vlc/plugins/access_output/libaccess_output_file_plugin.so
%{_libdir}/vlc/plugins/access_output/libaccess_output_http_plugin.so
%{_libdir}/vlc/plugins/access_output/libaccess_output_livehttp_plugin.so
%{_libdir}/vlc/plugins/access_output/libaccess_output_shout_plugin.so
%{_libdir}/vlc/plugins/access_output/libaccess_output_udp_plugin.so
%{_libdir}/vlc/plugins/audio_filter/liba52tospdif_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libaudio_format_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libaudiobargraph_a_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libchorus_flanger_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libcompressor_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libdolby_surround_decoder_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libdtstospdif_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libequalizer_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libgain_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libheadphone_channel_mixer_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libkaraoke_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libmono_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libnormvol_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libparam_eq_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libremap_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libsamplerate_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libscaletempo_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libsimple_channel_mixer_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libspatializer_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libspeex_resampler_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libstereo_widen_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libtrivial_channel_mixer_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libugly_resampler_plugin.so
%{_libdir}/vlc/plugins/audio_mixer/libfloat_mixer_plugin.so
%{_libdir}/vlc/plugins/audio_mixer/libinteger_mixer_plugin.so
%{_libdir}/vlc/plugins/audio_output/libadummy_plugin.so
%{_libdir}/vlc/plugins/audio_output/libalsa_plugin.so
%{_libdir}/vlc/plugins/audio_output/libamem_plugin.so
%{_libdir}/vlc/plugins/audio_output/libafile_plugin.so
%{_libdir}/vlc/plugins/audio_output/libjack_plugin.so
%{_libdir}/vlc/plugins/audio_output/libpulse_plugin.so
%{_libdir}/vlc/plugins/codec/liba52_plugin.so
%{_libdir}/vlc/plugins/codec/libadpcm_plugin.so
%{_libdir}/vlc/plugins/codec/libaes3_plugin.so
%{_libdir}/vlc/plugins/codec/libaraw_plugin.so
%{_libdir}/vlc/plugins/codec/libcc_plugin.so
%{_libdir}/vlc/plugins/codec/libcdg_plugin.so
%{_libdir}/vlc/plugins/codec/libcvdsub_plugin.so
%{_libdir}/vlc/plugins/codec/libddummy_plugin.so
%{_libdir}/vlc/plugins/codec/libdirac_plugin.so
%{_libdir}/vlc/plugins/codec/libdts_plugin.so
%{_libdir}/vlc/plugins/codec/libdvbsub_plugin.so
%{_libdir}/vlc/plugins/codec/libedummy_plugin.so
%{_libdir}/vlc/plugins/codec/libflac_plugin.so
%if %{with fluidsynth}
%{_libdir}/vlc/plugins/codec/libfluidsynth_plugin.so
%endif
%{_libdir}/vlc/plugins/codec/libg711_plugin.so
%{_libdir}/vlc/plugins/codec/libkate_plugin.so
%{_libdir}/vlc/plugins/codec/liblpcm_plugin.so
%{_libdir}/vlc/plugins/codec/libmpeg_audio_plugin.so
%{_libdir}/vlc/plugins/codec/libopus_plugin.so
%{_libdir}/vlc/plugins/codec/libpng_plugin.so
%{_libdir}/vlc/plugins/codec/librawvideo_plugin.so
%{_libdir}/vlc/plugins/codec/libschroedinger_plugin.so
%{_libdir}/vlc/plugins/codec/libspeex_plugin.so
%{_libdir}/vlc/plugins/codec/libspudec_plugin.so
%{_libdir}/vlc/plugins/codec/libstl_plugin.so
%{_libdir}/vlc/plugins/codec/libscte27_plugin.so
%{_libdir}/vlc/plugins/codec/libsubsdec_plugin.so
%{_libdir}/vlc/plugins/codec/libsubsusf_plugin.so
%{_libdir}/vlc/plugins/codec/libsvcdsub_plugin.so
%{_libdir}/vlc/plugins/codec/libt140_plugin.so
%{_libdir}/vlc/plugins/codec/libtelx_plugin.so
%{_libdir}/vlc/plugins/codec/libtheora_plugin.so
%{_libdir}/vlc/plugins/codec/libuleaddvaudio_plugin.so
%{_libdir}/vlc/plugins/codec/libvorbis_plugin.so
%if 0%{?suse_version} >= 1140
%{_libdir}/vlc/plugins/codec/libxwd_plugin.so
%endif
%{_libdir}/vlc/plugins/codec/libzvbi_plugin.so
%{_libdir}/vlc/plugins/control/libdbus_plugin.so
%{_libdir}/vlc/plugins/control/libdummy_plugin.so
%{_libdir}/vlc/plugins/control/libgestures_plugin.so
%{_libdir}/vlc/plugins/control/libhotkeys_plugin.so
%if 0%{?suse_version} >= 1140
%{_libdir}/vlc/plugins/control/libglobalhotkeys_plugin.so
%endif
%{_libdir}/vlc/plugins/control/liblirc_plugin.so
%{_libdir}/vlc/plugins/control/libmotion_plugin.so
%{_libdir}/vlc/plugins/control/libnetsync_plugin.so
%{_libdir}/vlc/plugins/control/liboldrc_plugin.so
%{_libdir}/vlc/plugins/demux/libaiff_plugin.so
%{_libdir}/vlc/plugins/demux/libasf_plugin.so
%{_libdir}/vlc/plugins/demux/libau_plugin.so
%{_libdir}/vlc/plugins/demux/libavi_plugin.so
%{_libdir}/vlc/plugins/demux/libdemux_cdg_plugin.so
%{_libdir}/vlc/plugins/demux/libdemux_stl_plugin.so
%{_libdir}/vlc/plugins/demux/libdemuxdump_plugin.so
%{_libdir}/vlc/plugins/demux/libdirac_plugin.so
%{_libdir}/vlc/plugins/demux/libes_plugin.so
%{_libdir}/vlc/plugins/demux/libflacsys_plugin.so
%{_libdir}/vlc/plugins/demux/libgme_plugin.so
%{_libdir}/vlc/plugins/demux/libh264_plugin.so
%{_libdir}/vlc/plugins/demux/libimage_plugin.so
%{_libdir}/vlc/plugins/demux/libmjpeg_plugin.so
%{_libdir}/vlc/plugins/demux/libmkv_plugin.so
%{_libdir}/vlc/plugins/demux/libmod_plugin.so
%{_libdir}/vlc/plugins/demux/libmp4_plugin.so
%{_libdir}/vlc/plugins/demux/libmpgv_plugin.so
%{_libdir}/vlc/plugins/demux/libnsc_plugin.so
%{_libdir}/vlc/plugins/demux/libnsv_plugin.so
%{_libdir}/vlc/plugins/demux/libnuv_plugin.so
%{_libdir}/vlc/plugins/demux/libogg_plugin.so
%{_libdir}/vlc/plugins/demux/libplaylist_plugin.so
%{_libdir}/vlc/plugins/demux/libps_plugin.so
%{_libdir}/vlc/plugins/demux/libpva_plugin.so
%{_libdir}/vlc/plugins/demux/librawaud_plugin.so
%{_libdir}/vlc/plugins/demux/librawdv_plugin.so
%{_libdir}/vlc/plugins/demux/librawvid_plugin.so
%{_libdir}/vlc/plugins/demux/libreal_plugin.so
%{_libdir}/vlc/plugins/demux/libsmf_plugin.so
%{_libdir}/vlc/plugins/demux/libsubtitle_plugin.so
%{_libdir}/vlc/plugins/demux/libts_plugin.so
%{_libdir}/vlc/plugins/demux/libtta_plugin.so
%{_libdir}/vlc/plugins/demux/libty_plugin.so
%{_libdir}/vlc/plugins/demux/libvc1_plugin.so
%{_libdir}/vlc/plugins/demux/libvobsub_plugin.so
%{_libdir}/vlc/plugins/demux/libvoc_plugin.so
%{_libdir}/vlc/plugins/demux/libwav_plugin.so
%{_libdir}/vlc/plugins/demux/libxa_plugin.so
%{_libdir}/vlc/plugins/gui/libskins2_plugin.so
%{_libdir}/vlc/plugins/lua/liblua_plugin.so
%{_libdir}/vlc/plugins/meta_engine/libfolder_plugin.so
%{_libdir}/vlc/plugins/meta_engine/libtaglib_plugin.so
%{_libdir}/vlc/plugins/misc/libaudioscrobbler_plugin.so
%{_libdir}/vlc/plugins/misc/libdbus_screensaver_plugin.so
%{_libdir}/vlc/plugins/misc/libexport_plugin.so
%if 0%{?suse_version} >= 1230 && 0%{?suse_version} != 1315
%{_libdir}/vlc/plugins/misc/libfingerprinter_plugin.so
%endif
%if 0%{?suse_version} >= 1220
%{_libdir}/vlc/plugins/misc/libgnutls_plugin.so
%endif
%{_libdir}/vlc/plugins/misc/liblogger_plugin.so
%{_libdir}/vlc/plugins/misc/libstats_plugin.so
%{_libdir}/vlc/plugins/misc/libvod_rtsp_plugin.so
%if 0%{?suse_version} >= 1140
%{_libdir}/vlc/plugins/misc/libxdg_screensaver_plugin.so
%endif
%{_libdir}/vlc/plugins/misc/libxml_plugin.so
%ifarch %{ix86} x86_64
%{_libdir}/vlc/plugins/mmx/libi420_rgb_mmx_plugin.so
%{_libdir}/vlc/plugins/mmx/libi420_yuy2_mmx_plugin.so
%{_libdir}/vlc/plugins/mmx/libi422_yuy2_mmx_plugin.so
#{_libdir}/vlc/plugins/mmx/libmemcpymmx_plugin.so
#{_libdir}/vlc/plugins/mmxext/libmemcpymmxext_plugin.so
%endif
%{_libdir}/vlc/plugins/mux/libmux_asf_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_avi_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_dummy_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_mp4_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_mpjpeg_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_ogg_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_ps_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_ts_plugin.so
%{_libdir}/vlc/plugins/mux/libmux_wav_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_copy_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_dirac_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_flac_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_h264_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_mlp_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_mpeg4audio_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_mpeg4video_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_mpegvideo_plugin.so
%{_libdir}/vlc/plugins/packetizer/libpacketizer_vc1_plugin.so
%{_libdir}/vlc/plugins/services_discovery/libbonjour_plugin.so
%{_libdir}/vlc/plugins/services_discovery/libmediadirs_plugin.so
%if 0%{?suse_version} >= 1140
%{_libdir}/vlc/plugins/services_discovery/libmtp_plugin.so
%endif
%{_libdir}/vlc/plugins/services_discovery/libpodcast_plugin.so
%{_libdir}/vlc/plugins/services_discovery/libpulselist_plugin.so
%{_libdir}/vlc/plugins/services_discovery/libsap_plugin.so
%{_libdir}/vlc/plugins/services_discovery/libudev_plugin.so
%{_libdir}/vlc/plugins/services_discovery/libupnp_plugin.so
%if 0%{?suse_version} >= 1140
%{_libdir}/vlc/plugins/services_discovery/libxcb_apps_plugin.so
%endif
%ifarch %{ix86} x86_64
%{_libdir}/vlc/plugins/sse2/libi420_rgb_sse2_plugin.so
%{_libdir}/vlc/plugins/sse2/libi420_yuy2_sse2_plugin.so
%{_libdir}/vlc/plugins/sse2/libi422_yuy2_sse2_plugin.so
%endif
%{_libdir}/vlc/plugins/stream_filter/libdecomp_plugin.so
%{_libdir}/vlc/plugins/stream_filter/libdash_plugin.so
%{_libdir}/vlc/plugins/stream_filter/libhttplive_plugin.so
%{_libdir}/vlc/plugins/stream_filter/librecord_plugin.so
%{_libdir}/vlc/plugins/stream_filter/libsmooth_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_autodel_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_bridge_plugin.so
%if 0%{?suse_version} >= 1230 && 0%{?suse_version} != 1315
%{_libdir}/vlc/plugins/stream_out/libstream_out_chromaprint_plugin.so
%endif
%{_libdir}/vlc/plugins/stream_out/libstream_out_delay_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_description_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_display_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_dummy_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_duplicate_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_es_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_gather_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_langfromtelx_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_mosaic_bridge_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_raop_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_record_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_rtp_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_setid_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_smem_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_standard_plugin.so
%{_libdir}/vlc/plugins/stream_out/libstream_out_transcode_plugin.so
%{_libdir}/vlc/plugins/text_renderer/libsvg_plugin.so
%{_libdir}/vlc/plugins/text_renderer/libtdummy_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libgrey_yuv_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libi420_rgb_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libi420_yuy2_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libi422_i420_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libi422_yuy2_plugin.so
%{_libdir}/vlc/plugins/video_chroma/librv32_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libyuy2_i420_plugin.so
%{_libdir}/vlc/plugins/video_chroma/libyuy2_i422_plugin.so
%{_libdir}/vlc/plugins/video_filter/libadjust_plugin.so
%{_libdir}/vlc/plugins/video_filter/libalphamask_plugin.so
%{_libdir}/vlc/plugins/video_filter/libanaglyph_plugin.so
%{_libdir}/vlc/plugins/video_filter/libantiflicker_plugin.so
%{_libdir}/vlc/plugins/video_filter/libatmo_plugin.so
%{_libdir}/vlc/plugins/video_filter/libaudiobargraph_v_plugin.so
%{_libdir}/vlc/plugins/video_filter/libball_plugin.so
%{_libdir}/vlc/plugins/video_filter/libblend_plugin.so
%{_libdir}/vlc/plugins/video_filter/libblendbench_plugin.so
%{_libdir}/vlc/plugins/video_filter/libbluescreen_plugin.so
%{_libdir}/vlc/plugins/video_filter/libcanvas_plugin.so
%{_libdir}/vlc/plugins/video_filter/libchain_plugin.so
%{_libdir}/vlc/plugins/video_filter/libclone_plugin.so
%{_libdir}/vlc/plugins/video_filter/libcolorthres_plugin.so
%{_libdir}/vlc/plugins/video_filter/libcroppadd_plugin.so
%{_libdir}/vlc/plugins/video_filter/libdeinterlace_plugin.so
%{_libdir}/vlc/plugins/video_filter/libdynamicoverlay_plugin.so
%{_libdir}/vlc/plugins/video_filter/liberase_plugin.so
%{_libdir}/vlc/plugins/video_filter/libextract_plugin.so
%{_libdir}/vlc/plugins/video_filter/libgaussianblur_plugin.so
%{_libdir}/vlc/plugins/video_filter/libgradfun_plugin.so
%{_libdir}/vlc/plugins/video_filter/libgradient_plugin.so
%{_libdir}/vlc/plugins/video_filter/libgrain_plugin.so
%{_libdir}/vlc/plugins/video_filter/libhqdn3d_plugin.so
%{_libdir}/vlc/plugins/video_filter/libinvert_plugin.so
%{_libdir}/vlc/plugins/video_filter/liblogo_plugin.so
%{_libdir}/vlc/plugins/video_filter/libmagnify_plugin.so
%{_libdir}/vlc/plugins/video_filter/libmarq_plugin.so
%{_libdir}/vlc/plugins/video_filter/libmirror_plugin.so
%{_libdir}/vlc/plugins/video_filter/libmosaic_plugin.so
%{_libdir}/vlc/plugins/video_filter/libmotionblur_plugin.so
%{_libdir}/vlc/plugins/video_filter/libmotiondetect_plugin.so
%if 0%{?suse_version} >= 1140 && 0%{?suse_version} != 1315
%{_libdir}/vlc/plugins/video_filter/libopencv_example_plugin.so
%{_libdir}/vlc/plugins/video_filter/libopencv_wrapper_plugin.so
%endif
%{_libdir}/vlc/plugins/video_filter/libposterize_plugin.so
%{_libdir}/vlc/plugins/video_filter/libpsychedelic_plugin.so
%{_libdir}/vlc/plugins/video_filter/libpuzzle_plugin.so
%{_libdir}/vlc/plugins/video_filter/libripple_plugin.so
%{_libdir}/vlc/plugins/video_filter/librotate_plugin.so
%{_libdir}/vlc/plugins/video_filter/librss_plugin.so
%{_libdir}/vlc/plugins/video_filter/libscale_plugin.so
%{_libdir}/vlc/plugins/video_filter/libscene_plugin.so
%{_libdir}/vlc/plugins/video_filter/libsepia_plugin.so
%{_libdir}/vlc/plugins/video_filter/libsharpen_plugin.so
%{_libdir}/vlc/plugins/video_filter/libsubsdelay_plugin.so
%if 0%{?suse_version} >= 1310 || 0%{?BUILD_ORIG}
%{_libdir}/vlc/plugins/video_filter/libswscale_plugin.so
%endif
%{_libdir}/vlc/plugins/video_filter/libtransform_plugin.so
%{_libdir}/vlc/plugins/video_filter/libwall_plugin.so
%{_libdir}/vlc/plugins/video_filter/libwave_plugin.so
%{_libdir}/vlc/plugins/video_filter/libyuvp_plugin.so
%{_libdir}/vlc/plugins/video_output/libcaca_plugin.so
%{_libdir}/vlc/plugins/video_output/libfb_plugin.so
%if 0%{?suse_version} >= 1140
%{_libdir}/vlc/plugins/video_output/libgl_plugin.so
%{_libdir}/vlc/plugins/video_output/libglx_plugin.so
%endif
%{_libdir}/vlc/plugins/video_output/libvdummy_plugin.so
%{_libdir}/vlc/plugins/video_output/libvmem_plugin.so
%{_libdir}/vlc/plugins/video_output/libvout_sdl_plugin.so
%if 0%{?suse_version} >= 1140
%{_libdir}/vlc/plugins/video_output/libxcb_window_plugin.so
%{_libdir}/vlc/plugins/video_output/libxcb_x11_plugin.so
%{_libdir}/vlc/plugins/video_output/libxcb_xv_plugin.so
%endif
%{_libdir}/vlc/plugins/video_output/libyuv_plugin.so
%{_libdir}/vlc/plugins/visualization/libvisual_plugin.so

%if 0%{?BUILD_ORIG}
%files codecs
%defattr(-,root,root)
%{_libdir}/vlc/plugins/access/libaccess_avio_plugin.so
%{_libdir}/vlc/plugins/audio_filter/liba52tofloat32_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libdtstofloat32_plugin.so
%{_libdir}/vlc/plugins/audio_filter/libmpgatofixed32_plugin.so
%{_libdir}/vlc/plugins/codec/libavcodec_plugin.so
%{_libdir}/vlc/plugins/codec/libfaad_plugin.so
%{_libdir}/vlc/plugins/codec/liblibmpeg2_plugin.so
%{_libdir}/vlc/plugins/codec/libtwolame_plugin.so
%{_libdir}/vlc/plugins/codec/libx264_plugin.so
%{_libdir}/vlc/plugins/codec/libvdpau_plugin.so
%{_libdir}/vlc/plugins/codec/libvaapi_plugin.so
%{_libdir}/vlc/plugins/demux/libavformat_plugin.so
%{_libdir}/vlc/plugins/video_filter/libpostproc_plugin.so
%endif

%files -n libvlc%{libvlc}
%defattr(-,root,root)
%{_libdir}/libvlc.so.%{libvlc}*

%files -n libvlccore%{libvlccore}
%defattr(-,root,root)
%{_libdir}/libvlccore.so.%{libvlccore}*

%files qt
%defattr(-,root,root)
%{_bindir}/qvlc
%{_libdir}/vlc/plugins/gui/libqt4_plugin.so

%files gnome
%defattr(-,root,root)
%{_libdir}/vlc/plugins/access/libaccess_gnomevfs_plugin.so

%files devel
%defattr(-,root,root)
%{_includedir}/vlc/
%{_libdir}/libvlccore.so
%{_libdir}/libvlc.so
%{_libdir}/pkgconfig/libvlc.pc
%{_libdir}/pkgconfig/vlc-plugin.pc

%changelog
* Wed Feb  4 2015 dimstar@opensuse.org
- Add vlc.changes as source so that we can reliably access it
  during build, even when using the .src.rpm.
* Thu Jan 22 2015 dimstar@opensuse.org
- Add vlc-CVE-2014-9625.patch: Fix various buffer overflows and
  null ptr dereferencing (boo#914268, CVE-2014-9625).
* Sun Nov  9 2014 seife+obs@b1-systems.com
- fix skins2 defaut.vlt generation with newer tar defaults (and
  remove the embedded build date from it on the way)
  vlc-2.1.5-fix-skins2-default-skin-creation.patch
- remove buildhost hostname from the binary to avoid republishing
* Thu Oct 30 2014 olaf@aepfle.de
- Convert BuildRequires from foo-devel to pkgconfig(foo)
* Fri Oct 24 2014 dimstar@opensuse.org
- First attempts on enabling build for SLE-12.
* Thu Oct  9 2014 vindex17@outlook.it
- Enable SSE2 instruction set for x86_64
* Tue Oct  7 2014 dimstar@opensuse.org
- Disable fluidsynth again: the crashes we had earlier are still
  not all fixed. They are less, but less common makes it more
  difficult to debug.
* Sun Oct  5 2014 olaf@aepfle.de
- Enable build for SLE_11
* Tue Sep 23 2014 vindex17@outlook.it
- Fix rpmlint warning about duplicates with fdupes
- Add missing BuildRequires:
  + fluidsynth-devel: SMF files playback
  + freerdp-devel: RDP support
  + libkde4-devel: KDE integration
  + libchromaprint-devel: Chromaprint stream output
  + libmlt6-modules: television broadcasting
  + LibVNCServer-devel: VNC support
  + opencv-devel: real-time computer vision support
  + xcb-util-keysyms-devel: better X integration
- Remome gcc-c++ and libqt4-devel because automatically installed
- Add 'suse_version' conditionals to the new BuildRequires
- Remove 'suse_version' conditionals from live555-devel & lua-devel
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 2.1.5:
  + Core: Fix compilation on OS/2.
  + Access: Stability improvements for the QTSound capture module.
  + Mac OS X audio output:
  - Fix channel ordering.
  - Increase the buffersize.
  + Decoders:
  - Fix DxVA2 decoding of samples needing more surfaces.
  - Improve MAD resistance to broken mp3 streams.
  - Fix PGS alignment in MKV.
  + Qt Interface: Don't rename mp3 converted files to .raw.
  + Mac OS X Interface:
  - Correctly support video-on-top.
  - Fix video output event propagation on Macs with retina
    displays.
  - Stability improvements when using future VLC releases side by
    side.
  + Streaming: Fix transcode when audio format changes.
  + Updated translations.
* Thu May 15 2014 olaf@aepfle.de
- Include also libglobalhotkeys_plugin.so which is build with old x11
* Thu May 15 2014 olaf@aepfle.de
- BuildRequire at least gnutls 3.0.20
* Fri May  2 2014 olaf@aepfle.de
- BuildRequire at least jack 1.9.7
* Thu Apr 24 2014 olaf@aepfle.de
- BuildRequire libtag-devel instead of taglib-devel to work around
  a resolver bug. A package name from external project is prefered
  over a provide from the same project.
* Tue Apr 15 2014 olaf@aepfle.de
- Require plain lua-devel instead of lua51-devel for 12.1 or older
* Sat Mar  8 2014 dap.darkness@gmail.com
- Fixed PowerPC builds.
* Sun Feb 23 2014 dimstar@opensuse.org
- Update to version 2.1.4:
  + Demuxers: Fix issue in WMV with multiple compressed payload and
    empty payloads.
  + Video Output: Fix subtitles size rendering on Windows.
  + Mac OS X:
  - Fix DVD playback regression.
  - Fix misleading error message during video playback on
    OS X 10.9.
  - Fix hardware acceleration memleaks.
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 2.1.3 (bnc#864422):
  + Core:
  - Fix broken behaviour with SOCKSv5 proxies
  - Fix integer overflow on error when using vlc_readdir
  + Access:
  - Fix DVB-T2 tuning on Linux.
  - Fix encrypted DVD playback.
  - Fix v4l2 frequency conversion.
  + Decoders:
  - Fix numerous issues (M2TS, VC1 interlaced, Lagarith, FFv1.3,
    Xvid) by updating codec libraries.
  - Bring fluidsynth back on Mac OS X
  - Fix some Opus crashes with some filters
  - Fix teletext crash on Windows
  + Demuxers:
  - Avoid an infinite recursion in MKV tags parsing
  - Fix an issue with some Vobsub tracks
  - Fix missing samples at the end of some wav files
  - Fix divide by 0 on ASF/WMV parsing
  + Audio output:
  - Fix audio device selection via command line on Mac OS X
  - Fix audio crashes on Mac OS X
  + Video Output:
  - Fix selection of DirectDraw as the default output for XP
  - Fix transform off-by-one issue
  - Fix screensaver disabling on Windows outputs
  - Fix DirectDraw device enumeration and multi-display output
  - Fix a potential crash when playing a fullscreen game at the same time as VLC
  + Stream output:
  - Fix 24bits audio MTU alignment in RTP
  - Fix record file names
  + Qt interface:
  - Fix minimal size possible on start
  - Fix a crash with the simple volume widget
  - Fix a crash in the audio menu building
  - Fix multimedia keys issues on Windows
  - Fix opening of DVD and BD folders on Windows
  + HTTP interface: Fix album art display on Windows.
  + Updated translations.
* Fri Dec 27 2013 claudiozumbo@gmail.com
- Add update-desktop-files BuildRequires and
  %%desktop_database_post/postun calls to respective scriptlets: Fix
  https://bugs.links2linux.org/browse/PM-108.
* Wed Dec 11 2013 dimstar@opensuse.org
- Update to version 2.1.2:
  + Audio output:
  - Fix digital playback on OS X when more than one audio device
    is installed.
  - Fix digital playback (SPDIF/HDMI) on Windows.
  - Fix stuttering or silent playback when using sound enhancers
    or external audio devices on OS X.
  - Improve responsiveness on OS X when playback starts or is
    being paused.
  - Improve responsiveness, silent playback intervals and
    reliability on iOS.
  + Demuxers:
  - Fix Vimeo and DailyMotion parsing.
  - Various WMV playback improvements and fixes.
  + Decoders:
  - Fix LPCM 20/24-bit decoding and 16 bits with channel padding.
  - Fix playback of some HEVC samples.
  + Video filters: Fix crash on deinterlace selection.
  + Qt interface:
  - Fix some streaming profiles when copy existed.
  - Improve A-B loop control.
  - Fix album art update when changing media.
  + Mac OS X interface adjustments.
  + Win32 installer: Kill running VLC process on uninstall/update.
  + Updated translations.
* Sat Nov 23 2013 dimstar@opensuse.org
- More features (by adding BuildRequires):
  + IDN Support (International Domain Names): libidn-devel
  + SFTP Access: libssh2-devel
  + HotKey Support: xcb-util-keysyms-devel
  + Complete SDL Stack: SDL_image-devel
  + ProjectM suppor (for openSUSE >= 12.3)
* Mon Nov 18 2013 dimstar@opensuse.org
- Update to version 2.1.1:
  + Core:
  - Fix random and reshuffling behaviour.
  - Fix recording.
  - Fix some subtitles track selection.
  + Decoders:
  - VP9 support in WebM.
  - HEVC/H.265 support in MKV, MP4 and raw files.
  - Fix GPU decoding under Windows (DxVA2) crashes.
  + Demuxers:
  - Fix crashes on wav, mlp and mkv and modplug files.
  - Support Speex in ogg files.
  - Fix some .mov playlists support.
  - Support Alac in mkv.
  - Fix WMV3 and palette in AVI.
  - Fix FLAC packetizer issues in some files.
  + Access:
  - Fix DVB options parsing.
  - Fix DeckLink HDMI input.
  - Fix HTTPS connectivity on OS X by loading root certificates
    from Keychain.
  + Audio output:
  - Fixes for DirectSound pass-through.
  - Fixes for OSS output, notably on BSD.
  + Interfaces:
  - Fix HTTP interface infinite loop.
  - Fix D-Bus volume setting.
  + Qt:
  - Reinstore right click subtitle menu to open a subtitle.
  - Fix saving the hotkeys in preferences.
  - Fix saving the audio volume on Win32, using DirectSound.
  - Fix play after drag'n drop.
  - Fix streaming options edition and scale parameter.
  + Stream out:
  - Fix transcoding audio drift issues.
  - Fix numerous audio encoding issues.
  + Win32 installer:
  - Important rewrite to fix numerous bugs, notably about
    updates.
  - Simplification of the upgrade mechanism.
  + Mac OS X interface:
  - Reintroduce the language selector known from pre-2.1
    releases.
  - Fix fullscreen behaviour and various crashes.
  - Fix about dialog crash in Japanese.
  - Fix crashes on proxy lookups.
  - Fixes on the playlist and information behaviours.
  - Fixes on the streaming dialogs.
  - Improves interface resizings.
  + Updated translations.
- Pass --with-default-font=[path] and
  - -with-default-monospace-font=[path] to configure.
- Drop fix_font_path.patch: replaced with configure parameters
  above.
* Wed Nov 13 2013 dimstar@opensuse.org
- Recommend 'vlc' by vlc-qt: some users might go installing the UI
  package directly. Having Qt most likely also means the user has X,
  so we at least recommend the vlc package relying on X.
* Thu Nov  7 2013 hrvoje.senjan@gmail.com
- Force creation of plugins cache in vlc-nox %%post, instead of just
  touching the file, for details see
  https://trac.videolan.org/vlc/ticket/9807#comment:2
* Thu Oct 24 2013 dimstar@opensuse.org
- Update License: A lot has been relicensed to LGPL-2.1.
* Mon Oct 21 2013 hrvoje.senjan@gmail.com
- Make vlc build on OBS for openSUSE 12.3 - BuildRequire
  pkgconfig(libswscale) and live555-devel on >= 13.1, and on
  BUILD_ORIG case
* Sat Oct 12 2013 scarabeus@opensuse.org
- Drop support for < 12.2 as it does not build anyway
  * Removal of pulseaudio subpackage and incorporating it to the
    noX package.
  * Cleanup of the dependencies and configure switches we don't
    need to use anymore.
- Add lang subpackage as it was most of what was noX package
  containing. This way we can reduce the size and use noarch there.
- Touch the ghosted file in %%post to make rpmlint happy
- Fix __DATE__ and __TIME__ usage so we do not rebuild so often.
- Drop obsolete configure options which are no longer around
- Disable xcb switch as we no longer build for such old distros.
* Wed Oct  2 2013 wbauer@tmo.at
- Re-add and adapt 0001-no-return-in-non-void.patch: fixes build on
  openSUSE versions other than Factory
* Wed Oct  2 2013 guillaume@opensuse.org
- Add support to openGL ES 2 (enabled by default for %%arm):
  + Introduce bcon_with(out) opengles.
  + If enabled, pass --enable-gles2 --enable-egl to configure.
  + Adjust the files section for that.
* Wed Oct  2 2013 guillaume@opensuse.org
- Add vdpau support to -codecs package (BUILD_ORIG):
  + BuildRequire libvdpua-devel
  + Adapt files section.
* Tue Oct  1 2013 dimstar@opensuse.org
- Only enable GME support on openSUSE >= 12.00 (disable on SLE11).
* Wed Sep 25 2013 dimstar@opensuse.org
- Update to version 2.1.0:
  + Important changes:
  - The licenses of numerous modules have changed from GPLv2+ to
    LGPLv2.1+.
  - Discontinued support for PowerPC-based Macs; VLC now requires
    Mac OS X 10.6+.
  - The --with-tuning and --without-tuning options are removed;
    to tune compilation for a specific processor type, set CFLAGS
    manually.
  + LOTS of updates all over. See NEWS for a full overview.
- Rebase fix_font_path.patch.
- Drop 0001-no-return-in-non-void.patch: no longer needed.
- Drop vlc-avcodec-encoder-single-threaded.patch: fixed upstream.
- Drop ppc64_altivec.patch: fixed upstream.
* Sat Sep 21 2013 dimstar@opensuse.org
- Drop fluidsynt-devel BuildRequires: the fluid plugin is known to
  introduce a lot crashes at no gain from functionality PoV.
* Sat Sep  7 2013 dimstar@opensuse.org
- If we have a smblcient.pc available (meaning, we build against
  samba 4), we export the output of pkg-config --cflags smbclient
  into CFLAGS. Fixes build with Samba 4.0.
* Fri Aug  9 2013 dvaleev@suse.com
- Add ppc64_altivec.patch: Enable altivec for powerpc64
  (backport cce2cdb0dd246fa9669378f5a3b967464c88bf20)
- Add autoreconf call in build section, as above patch touches the
  build system.
* Fri Aug  9 2013 dvaleev@suse.com
- Package altivec plugins on powerpc
* Sat Aug  3 2013 dimstar@opensuse.org
- Update to version 2.0.8a:
  + always hide menu bar for fullscreen on osx redacted (vlc#9040).
  + macosx: fix double release
  + avcodec audio decoder: update block pointer.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 2.0.8:
  + Access:
  - Fix ISDB-S tuning.
  - Fix crash in QTsound.
  - Fix screen mouse file location.
  - Fix invalid memcpy in MMS access.
  + Demux:
  - Fix use after free in sgimb.
  - Improve resistance and checking against malformed MKV files.
  + Decoders:
  - Fix crash in the libavcodec module.
  + Mac OS X:
  - Fix interface crashes.
  - Fix autostart playback option.
  - Respect "playlist-autostart" option.
  + Updated translations.
- Drop vlc-vaapi.patch: fixed upstream.
- Add vlc-avcodec-encoder-single-threaded.patch: disable
  multithreading for avcodec encoder for now. Taken from git.
* Sun Jul 28 2013 reddwarf@opensuse.org
- Add pkgconfig(dirac) BuildRequires to enable Dirac support.
* Sat Jul 13 2013 dimstar@opensuse.org
- Add vlc-vaapi.patch: Make vaapi decoder compatible with latest
  libva changes.
* Thu Jul  4 2013 hrvoje.senjan@gmail.com
- Update to version 2.0.7:
  + Input:
  - Fix playback termination when switching ES tracks
    (PowerPC only)
  - Fix memory exhaustion vulnerability when playing specifically
    crafted playlist files
  + Decoders:
  - Fix WMA Pro, MPEG 4 ALS, APE, MLP and ADPCM-IMA4 playback
  + Encoders:
  - Fix audio encoding for numerous codecs, notably mp3 and aac
  + Muxers:
  - Fix noticeable memory leak when creating AVI files
  + Video output:
  - Fix crash when using libvlc in 3rd party applications
    (Mac only)
  + Mac OS X Interface
  - Minor improvements
  - Fix issue which could lead to loss of media files created
    through transcoding
* Tue Jun 11 2013 dvaleev@suse.com
- Enable SSE for x86 only
* Tue Jun  4 2013 reddwarf@opensuse.org
- Enable gme:
  + Pass --enable-gme to configure
  + Add pkgconfig(gme) BuildRequires
* Thu May  9 2013 dimstar@opensuse.org
- Enable opus codec:
  + Pass --enable-opus to configure
  + Add libopus-devel BuildRequires
* Tue May  7 2013 dimstar@opensuse.org
- Move live555-devel BuildRequires to the unconditional area:
  live555 has been added to Factory and is safe for distribution.
- Move the live555 demuxer from vlc-codecs to vlc-noX.
- Add unconditional --enable-live555 parameter to configure, and
  remove the conditional enable/remove-live555, based on BUILD_ORIG.
* Thu May  2 2013 dimstar@opensuse.org
- Add pkgconfig(libswscale) BuildRequires: improve the quality of
  the video filters.
- Unconditionally pass --enable-swscale to configure.
- Move the swscale videofilter out of the -codecs package to the
  - noX package.
* Thu Apr 25 2013 dimstar@opensuse.org
- Change libdvbpsi-devel BuildRequires to require version < 1.0.
  VLC 2.0.6 is not able to cope with the new API yet.
* Wed Apr 10 2013 dimstar@opensuse.org
- Change live555 BuildRequires to live555-devel: in fact we do
  require the devel package, which for historical reasons just
  happens to provide live555 as well.
* Tue Apr  9 2013 dimstar@opensuse.org
- Update to version 2.0.6:
  + Access:
  - Fix HTTPS playback with some certificates previously
    rejected.
  + Audio Output:
  - Fix lookup for device names in auhal plugin
  + Demuxers:
  - Fix crash with broken asf files (SA-1302)
  - Fix MKV behaviour with unknown or new ebml elements
  - Fix use-after-free crash in Ogg demuxer
  - Fix regression on some paletted codecs in AVI
  - Fix ALAC in mp4 regression
  - Improvements to the vimeo playlist parser
  + Decoders:
  - Fix GPU decoding on Intel HD 2000/3000 cards on Windows
  - Fix FLAC 6.1 and 7.1 channel layout
  - Fix crashes in HTML srt subtitles
  - 3rd party codecs updates
  + Mac OS X fixes
  + Qt: Fix clearing of Media Info panel on dialog exit
  + GNU/Linux:
  - Numerous D-Bus and MPRIS2 improvements
  - Reject broken versions of PulseAudio
  + Windows:
  - Fix uninstallation in different location than C:\
  + Updated translations.
* Thu Apr  4 2013 dimstar@opensuse.org
- Fix files section for openSUSE 11.4 and 12.1.
* Thu Apr  4 2013 dimstar@opensuse.org
- Introduce BUILD_ORIG build flag, in order to build without
  'legally difficult' extensions in OBS.
* Tue Jan 22 2013 dimstar@opensuse.org
- Add --enable-png configure parameter to enable png support
  (pointed out by Alin).
* Mon Dec 17 2012 dimstar@opensuse.org
- Add -msse to CFLAGS: this helps us over GCC 4.3 being used in
  SLE 11SP2.
* Sun Dec 16 2012 dimstar@opensuse.org
- Update to version 2.0.5:
  * See http://www.videolan.org/vlc/releases/2.0.5.html
* Sun Oct 21 2012 dimstar@opensuse.org
- Disable ncurses build: will need to work on finding the right
  ncursesw integration steps.
* Thu Oct 18 2012 dimstar@opensuse.org
- Update to version 2.0.4:
  + See NEWS for details.
* Thu Jul 19 2012 dimstar@opensuse.org
- Update to version 2.0.3
* Mon Jul  2 2012 dimstar@opensuse.org
- Upadate to version 2.0.2:
    Rework of the Mac OS X interface
    Fix video output for old graphic cards on Windows XP, which are using DirectX
    Fix video output on old Macs, notably PowerPC and GMA950 intel Macs.
    Support for HiDPI, aka Retina Display
    Support for H264 v4l2 devices on Linux
    Translations updates and new Scottish Gaelic translation
    Fixes for splitted RAR, MKV segmented, mp4 and Real media files playback.
    Rewrite of the Digital TV module on Windows
    Enhancements in HLS, Blu-Ray and various codecs support
    Fixes for subtitles auto-detection
    Fixes on Qt, skins2 and web interfaces
* Fri Mar 30 2012 dimstar@opensuse.org
- Inject -L%%{_libdir}/live into CFLAGS and CXXFLAGS for live555 to
  be built. The static lib is in a non-standard place and not
  detected by configure scripts.
* Mon Mar 19 2012 dimstar@opensuse.org
- Update to version 2.0.1:
  + Lots of bug fixes
  + For a full list, see NEWS file in the package.
* Fri Feb 17 2012 dimstar@opensuse.org
- Update to version 2.0.0 final.
* Wed Feb  1 2012 dimstar@opensuse.org
- Update to version 2.0.0 rc1
* Wed Jan 18 2012 dimstar@opensuse.org
- Add xorg-x11-devel BuildRequires: fixes build on Factory.
* Wed Jan 11 2012 dimstar@opensuse.org
- Use lua 5.1 on Factory.
* Thu Dec 22 2011 dimstar@opensuse.org
- Update to version 1.1.13:
  + This release was necessary due to a security issue in the TiVo
    demuxer.
* Fri Dec  2 2011 dimstar@opensuse.org
- Add libtool BuildRequires, as the chroot no longer implicitly
  provides it.
* Wed Nov 23 2011 dimstar@opensuse.org
- Build libva dependencies only for 11.4+.
* Fri Oct  7 2011 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.12:
  + Audio outputs:
  - Mac OS X / auhal: multiple fixes for the Digital Audio output
    (S/PDIF) including support for OS X Lion
  - Multiple fixes and improved synchronization for PulseAudio
    support
  - Support for AC-3 and DTS passthrough with PulseAudio 1.0
  + Unix port:
  - Fix build compatibility with taglib < 1.6 and Xulrunner 1.9.1
  + Misc:
  - Fix crashes with Japanese locale on OS X
  - Minor fixes for Webplugin under Win32, AVI demuxer, smem and
    AudioScrobbler
  - Fix crash in HTTP and RTSP server (stream output or Web
    interface)
- Drop vlc-1.1.11-taglib.patch: Fixed upstream
* Wed Aug 24 2011 dominique-vlc.suse@leuenberger.net
- Add libgcrypt-devel BuildRequires.
* Mon Jul 18 2011 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.11:
  + Security:
  - Fix buffer overflows in the RealMedia demuxer (CVE-2011-2587)
    and the AVI one (CVE-2011-2588).
  + Mozilla/ActiveX webplugin:
  - Fullscreen mode is fixed on Win32
  - Very simple fullscreen controller is visible on Win32
  + Demuxers/Meta Readers:
  - Better support for cover art embedded in mp4, wma
  + Muxers/Output:
  - Fix AVI muxer so the generated files are readable on other
    players
  + Extensions:
  - Multiple fixes for crashes and malfunctionning issues
  + Qt Interface:
  - Fix quitting on Linux
  - Fix opening of VIDEO_TS folders through the open disc dialog
    on Windows
  - Miscellaneous
  + Updated translations.
- Add vlc-1.1.11-taglib.patch: Fix build on openSUSE <= 11.2 with
  taglib 1.5.
* Mon Jul 11 2011 dominique-vlc.suse@leuenberger.net
- Remove PortAudio-devel BuildRequires. This is long obsolete.
* Tue Jun 14 2011 dominique-vlc.suse@leuenberger.net
- Update to 1.1.0
* Sun Apr  3 2011 dominique-vlc.suse@leuenberger.net
- Add vlc-youtube.patch: fix youtube playback. Hack patch from
  upstream git repository, commit id d938db.
* Tue Mar 15 2011 dominique-vlc.suse@leuenberger.net
- Update to 1.1.8:
  + Interfaces:
  - Oldrc interface is again the default RC interface, on Windows
  - Luarc, luahttp and luatelnet fixes
  - Qt and Mac OS X fixes
  - numerous Skins2 fixes, notably winamp2 skins
  + Encoder:
  - new libschroedinger-based Dirac codec encoder, faster than the
    current one
  + Access/Demuxers/Codecs:
  - Subtitles auto-detection is back for .txt files
  - vod/rtsp server and rtsp input fixes
  - mp4 demuxer improvements
  - ogg, rstp input, video filters minor fixes
  - taglib's replaygain is fixed for mp3
  - vobsub support has an improved auto-detection
  - fix a crash in malformed ape files
  + Miscellaneous fixes in:
  - Pulseaudio audio output, notably for usb cards
  - Stacktraces are now limited in size on Windows
  - Video resolution is now limited to 8192x8192, for security
    reasons (CORE-2011-0208)
  - Configure and build system improvements
  - DirectShow and BDA build headers have been updated
- Drop patches that came from upstream git:
  + vlc-matroska.patch
  + vlc-upnp-assert.patch
* Sat Mar 12 2011 dominique-vlc.suse@leuenberger.net
- Add 0001-KDE-Add-smb-to-the-supported-protocols-we-can-get-fi.patch
* Wed Feb 23 2011 dominique-vlc.suse@leuenberger.net
- Own _datadir/kde4/apps, so we do not have to rely on meta-
  package kde4-filesystem, which does not exist in Fedora.
- Remove kde4-filesystem BuildRequires.
* Sat Feb 19 2011 dominique-vlc.suse@leuenberger.net
- Add vlc-matroska.patch: Fix build with new matroska version.
  Multi Tag no longer exists.
* Mon Jan 31 2011 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.7:
  + Linux port:
  - Integration with the KDE GUI platform is disabled due to KDE
  - bugs #234484 and #260719.
  + Mac OS X port:
    + Updated live555 library to fix playback of RTSP and Freebox
    streams
  + Running VLC in 64bit mode requires Mac OS X 10.6.0 or later for
    speed and stability reasons
  + Demuxers:
  - Fix for Matroska / WebM remote code execution vulnerability.
    VideoLAN-SA-1102
  + Updated translations.
- Changes from version 1.1.6.1:
  + Fix libnotify, lirc, pulse compilation and packaging for
    Unix/Linux
- Drop patches: vlc-lirc.patch and
  0001-Libnotify-depends-on-a-GTK-version-can-be-gtk-2.0-or.patch
* Mon Jan 24 2011 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.6:
  + Audio output:
  - Multiple fixes and improvements on PulseAudio output
  + Access:
  - Fix the Audio CD crash when looking for CDDB metadata on
    Windows
  + Decoders:
  - Support for MPC SV7 and SV8 on Windows and Mac OS X (Unix was
    already working)
  - Enabled FluidSynth MIDI playback plugin on Mac OS X
  - Faster VP8/Webm decoding with recent codecs libraries
  + Demuxers:
  - Fix Buffer overflow in Real demuxer CVE-2010-3907 /
    VideoLAN-SA-1007
  - Fix some asf/wmv seeking issues, notably when seek didn't go
    to a keyframe
  - Support for 24-bits PCM over RTP (audio/L24)
  + Subtitles and renderer:
  - Do not auto-detect .txt files for subtitles
  - Mark more freetype options as safe
  - Mac OS X: fixed fontconfig cache creation
  - Fix heap corruption in subtitle decoders, potentially
    exploitable
  + Visualization:
  - Fix projectM visualization for Linux in all locales
  - Fix projectM visualization support for Windows
  - Various projectM improvements: the module should be working
    now
  - Fix goom crash on Windows XP and Mac OS X
  + Interfaces:
  - Qt4: fixes for media keys processing and MCE remotes
  - Qt4: various fixes and portability improvements
  - KDE: work-around open dialog first slow opening because of
    KMimeTypeRepository
  + Miscellaneous fixes:
  - KDE device solid actions
  - XDG screensaver
  - Transcode integer overflow
  - HTTP Icy metadata reading
  - Windows: revert to 1.1.4 performance timers
  + Updated translations.
- Add vlc-lirc.patch: fix build of the lirc module. Taken from git.
* Sun Jan 16 2011 dominique-vlc.suse@leuenberger.net
- No loner package locale co.
* Fri Nov 19 2010 dominique-vlc.suse@leuenberger.net
- Add vlc-upnp-assert.patch: fix build of upnp plugin.
* Sat Nov 13 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.5:
  + Security:
  - Fix a Windows crash on accessing Network Shared files/drives,
    VideoLAN-SA-1006
  + Services Discovery:
  - Integration in the playlist, of a list of web shows,
    provided by channels.com
  + Demuxers:
  - Game Music Emu (GME) plugin rewritten, using the proper C API
  - DVDnav and DVDread fixes for encoding and misc issues
  - Playback of live http .Webm streams
  - Taglib thread-safety fix
  + Decoders:
  - Fix decoding of H264 using DxVA2 using Intel IGP, thanks to
    the donation from "Puget Systems"
  + Skins:
  - Add an icon to VLC on Linux
  + Video Output:
  - fix a bug that could lead to 100%% CPU usage on XCB
  + Interfaces:
  - fix for Qt bug where VLC didn't exit properly on some Windows
    XP configuration
  - fixes on luatelnet and luarc
  + Miscellaneous crashes and fixes in various plugins (telnet,
    live555, theora and TS-mux, Qt)
  + libLVC:
  - add libvlc_media_new_fd() to play directly file descriptors
    (not Win32/Win64)
  - Miscellaneous fixes
  + Updated translations.
* Wed Oct 20 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.4.1:
  + Demuxers:
  - DVDnav and DVDread fixes for encoding and misc issues
  - Playback of live http .Webm streams
  + Decoders:
  - Fix decoding of H264 using DxVA2 using Intel IGP, thanks to
    the donation from "Puget Systems"
  + Skins:
  - add an icon to VLC
  + Uodated translations.
* Mon Sep  6 2010 dominique-vlc.suse@leuenberger.net
- Add libtwolame-devel BuildRequires
* Fri Aug 27 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.4:
  + Win32:
  - Fix a security issue when loading DLLs, especially in Qt4
    and dmo modules, See VideoLAN-SA-1005
  - Fix folders opening from the interface
  + Updated translations.
- Add gdk-pixbuf-devel BuildRequires for openSUSE 11.4+
- Add gtk2-devel BuildRequires and add new patch:
  0001-Libnotify-depends-on-a-GTK-version-can-be-gtk-2.0-or.patch
* Thu Aug 19 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.3:
  + Access and demuxers:
  - fixes for FTP relatives path and FTP directory support
  - fix for podcasts parsing
  - DVD: fix an assert error and various memory leaks
  + Taglib:
  - fix NULL dereferences, as reported by FortiGuard Lab,
    CVE-2010-2937 / VideoLAN-SA-1004
  + Playlist:
  - fix a regression where the wrong entry was played
  - fix m3u playlists exports
  + Skins2:
  - fix video autoresize behaviour
  + updated translations
* Tue Aug  3 2010 dominique-vlc.suse@leuenberger.net
- BuildRequire libmatroska-devel instead of libmatroska.
* Fri Jul 30 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.2:
  + Demuxers:
  - Avformat fps displaying fix
  - TS, fix an issue where some programs would get dropped
    (fixes DVB issues too)
  + Audio filters:
  * fix timestamps handling on some filters that provoqued issues
    when playback of mono streams, especially on Windows
  + Windows:
  - fix a bug in direct3d video output with old nVidia drivers
    that broke video playback with overlay (YUV->RGB)
  - fix console output encoding
  + Interface and extensions:
  - Youtube and other scripts updates
  - Misc fixes in Qt4 (especially VLM and EPG dialogs) and MacOS
    interface.
* Tue Jul 20 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.1:
  + libVLC:
  * Support for the new capabilities: libvlc_adjust_Enable,
    libvlc_adjust_Contrast, libvlc_adjust_Brightness,
    libvlc_adjust_Hue, libvlc_adjust_Saturation,
    libvlc_adjust_Gamma
  * Various fixes and crash preventions, especially when video
    functions were called early
  * libvlc_media_player_set_pause() can force the pause state,
    whereas libvlc_media_player_pause() would only toggle it.
  * libvlc_set_user_agent() configures the "user agent" strings
    used for some protocols (HTTP, PulseAudio...).
    This replaces the --http-user-agent and the former
  - -user-agent libvlc_new() parameters.
  * libvlc_video_set_callbacks() and libvlc_video_set_format()
    allow grabbing video frames from a chosen memory location in
    real-time.
    This replace the ugly --vmem-* libvlc_new() parameters in
    previous versions.
    See http://wiki.videolan.org/LibVLC_SampleCode_SDL as an
    example.
  * libvlc_audio_get_delay() and libvlc_audio_set_delay()
    configure the delay between audio and video/subpictures for
    the current input.
  + Stream output:
  * Fix h264 streaming in ts
  + Decoders/Demuxers:
  * Fix performance issues with GPU decoding using DxVA2 using
    ATI graphic cards You NEED ATI Catalyst 10.7
  * Fix :program selection in TS and DVB-T
  * Fixes and improvements for MKV, Avformat and Avcodec modules
  * Fix mod (.xm, .s3m, .it) files support on Windows and Mac
    builds
  + Linux port:
  * Fix pulse closing
  * VAAPI small improvements, notable for FourCC selection for
    extraction
  + Interfaces:
  * Qt: fix preferences, hotkeys, messages and some fulscreen
    behaviour
  * Skins: support for mousewheel in fullscreen, fix
    radialsliders
  * Http: fix fullscreen toggle
  + Updated translations.
* Sat Jul  3 2010 dominique-vlc.suse@leuenberger.net
- Add lirc-devel to BuildRequires to actually build the lirc
  interface. Thanks to Rob Verduijn for reporting this error.
* Mon Jun 21 2010 dominique-vlc.suse@leuenberger.net
- Update to 1.1.0:
  + This is a major release, adding major features, notably:
  - GPU and DSP decoding on selected platforms
  - New support for codecs, demuxers and muxers
  - Lua extensions and Lua content extensions (luaSD)
  - Improved interfaces
  - Video Output rework
  - Removal of lots of modules, rewrite of many
  - Improved performances, in CPU, RAM and I/O
  - New libVLC and bindings
  - New or improved ports on misc platforms
  + And so many bugs and other features...
* Wed Jun 16 2010 dominique-vlc.suse@leuenberger.net
- Update to rc4
* Fri Jun 11 2010 dominique-vlc.suse@leuenberger.net
- Update to rc2
- BuildRequires SDL_image-devel
- Remove obsoleted switches from configure call.
* Thu Jun 10 2010 dominique-vlc.suse@leuenberger.net
- Add git-rollup.patch.bz2 to rollup to current git. Supposed
  to fix various crashers we see lately in 1.1rc2.
* Tue Jun  8 2010 dominique-vlc.suse@leuenberger.net
- BuildRequire libva-devel on openSUSE 11.2+
* Sun Jun  6 2010 dominique-vlc.suse@leuenberger.net
- Update to 1.1.0 RC 2: Final to be expected soon.
* Wed May 26 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.1.0 RC
* Mon Apr 26 2010 root@localhost
- BuildRequire appropriate xulrunner version.
* Sat Apr 24 2010 dominique-vlc.suse@leuenberger.net
- Patched tarball uploaded, as older versions of openSUSE
  seem not able to properly bootstrap it. The patch applied to the
  source tarball is vlc-globalhotkey-with-old-xcb-keysyms.patch.
* Fri Apr 23 2010 dominique-vlc.suse@leuenberger.net
- Add vlc-libpng14.patch, taken from git master, commit ffa6a2f.
* Thu Apr 22 2010 dominique-vlc.suse@leuenberger.net
- Update to version 1.0.6:
  + Access:
  * Fix crash on FTP URI with no file path
  + Decoders/Packetizers:
  * Fix overflows in A/52, DTS, MPEG Audio and subtitles support
  + Demuxers:
  * Update LUA script for Youtube pages
  * Fix crashes in AVI, ASF and Matroska files
  * Fix crashes on malformatted ZIP archives
  * Fix crashes and leaks in the FFmpeg/avformat plugin
  * Fix crash on invalid XSPF playlist
  + X11 port:
  * Partial Xlib threading fixes
  + Interfaces:
  * Fix crash (use after free) in Qt4 bookmarks
  * Fix a few crashes in Qt4 playlist
  + Removed modules:
    RTMP input and output are removed due to security problems.
    Please update to VLC 1.1.0 which provides an FFmpeg-based RTMP
    input if needed.
  + Updated translations.
- Changes from version 1.0.5:
  + Decoders:
  * SubRip extra styles improvements
  * Fix potential crashes in SSA and svg decoders
  + Mac OS X Interface:
  * Improved support for the 2009 Apple Remote
  + Windows port:
  * Use of gcc 4.4.2 to compile instead of gcc 4.2. This might
    slightly increase performance and fix x264 issues
* Thu Dec 10 2009 dominique-vlc.suse@leuenberger.net
- Update to version 1.0.4:
  + Audio outputs:
  * Fix deadlocks in the audio output core
  * Make PulseAudio the default output if available
  + Video outputs:
  * Fix fullscreen mode with KDE 4.3.3 and other window managers
  * Fix incompatibility with cairo-dock and compositing
  + Input:
  * Fix DVB scanning regression from VLC 1.0.3
  * Support for XZ-compressed byte stream (LZMA algorithm)
  + Playlist:
  * Support for .m3u8 playlist files (UTF-8 M3U)
  + Unix:
  * Support for xcb-keysyms version 0.3.4 or higher
  * Fix globalhotkeys on FreeBSD
  + Qt4 interface:
  * Fix opening V4L version 1 devices
  * Fix default destination ports in the streaming wizard
* Fri Oct 30 2009 dominique-vlc.suse@leuenberger.net
- Update to version 1.0.3
  + Video outputs:
  - Fix video quality when resizing the video on Windows Vista
    and 7, due to regressions in most popular drivers
  - New deinterlacers modules based on yadif and yadif(x2)
    algorithms
  + Decoders:
  - Windows version supports now natively the WMA Professional
    codec, as it didn't work in the packaged version of 1.0.2
  - Fix downmixing of particual 4.0 AC-3 audio tracks
  + Encoders:
  - x264 has profile-limitter, like:
    [#]transcode{vcodec=h264,venc=x264{profile=baseline,level=12}..}
  + Input:
  - Update for appletrailers lua script
  - Fixes on the RAR stream filter
  - Fix for E-AC3 in ATSC/TS streams
  - Various fixes for v4l and v4l2
  - Fix a crash in mjpeg demuxer
  + Service discovery:
  - New udev module for Linux
  + Qt4 interface:
  - Fixes on the playlist and the stream output panels
  + Updated translations.
* Tue Sep 29 2009 dominique-vlc.suse@leuenberger.net
- Add 540_all_x264.patch to build with x264 >= 0.76. Patch copied
  from gentoo portage.
* Mon Sep 21 2009 dominique-vlc.suse@leuenberger.net
- Update to version 1.0.2
  + Decoders:
  - Native support for WMA Professional, without the use of the
    Win32 dlls
  - Fix issues in subtitles, especially SSA ones
  - Various fixes on theora and ogg
  + Demuxers:
  - Various fixes for EPG support in MPEG-TS demuxer
  - Fixes for potential stack overflow in .avi, .mp4 and .asf
    demuxers
  + Access:
  - Fixes for v4l2 devices
  - Fixes for dvb-c channels-scanning
  + Qt Interface:
  - Fix some playlist sorting issues
  + Encoders:
  - MPEG2 transrate stream output removed
  - x264 default-values closer to x264.exe defaults.
  - x264 rc-behaviour fixes:
    . if user defines qp-value, CQP-mode is used
    . otherwise if user defines vb=0, CRF-mode is used
    . otherwise ABR-mode is used
  - x264 set vbv-bufsize/vbv-maxsize better if user hasn't
    defined these:
    . ABR mode set vbv-max-bitrate=bitrate
    . vbv-bufsize is bitrate * seconds between keyframes
    (keyint/fps)
  + Playlist:
  - Lua scripts for Mpora and Vimeo playback
  + Updated translations.
* Mon Aug 17 2009 dominique-vlc.suse@leuenberger.net
- Add vlc-1.0.1-libass4.patch to support newer libass. Patch
  taken from upstream commit 019359b5a5.
* Mon Jul 27 2009 dominique-vlc.suse@leuenberger.net
- Update to version 1.0.1
  + Demuxers:
  * Fix wmv/asf issues that caused audio to drop
  * Various fixes for ac3, mp3, dts and stability for wav format
  * Fix seek in RTSP in conformity to RFC 2326
  * Fix Dailymotion access script
  * Fix crashes in xspf files handler
  * Fix seeking and timing issues in some flv files on Windows
    version
  + Access:
  * Add extra caching for files on network shares
  * Prevent integer underflow in Real pseudo-RTSP module,
    discovered by tixxDZ, DZCORE Labs, Algeria
  + Decoders:
  * Fix seeking in mpeg2 video files
  * Improve SSA subtitles rendering
  * Update most codecs for the Windows and Mac version
  + Muxers:
  * Fix sound recording of .flv files with mp3 audio
  + Qt Interface:
  * Possibility to change the opacity level of the Fullscreen
    controller
  * Fix various crashes and VIDEO_TS folders opening
  + Mac OS X Interface:
  * Added options to disable support for Apple Remote and Media
    Keys
  * Fixed options for Volume, Last.fm password and Subtitle
    Encoding
  * Fixed redraw issues when autosizing the video window
  * Preferences panel now includes help through tool-tips
  * More reliable Information and Messages panels
  * Fix various crashes
  + Windows port:
  * The ZVBI module is now available for Windows, for complete
    teletext support
  + Update translations.
* Tue Jul  7 2009 dominique-vlc.suse@leuenberger.net
- Update to 1.0.0
  * See http://git.videolan.org/?p=vlc.git;a=blob;f=NEWS;h=777764
* Thu Jun 18 2009 dominique-vlc.suse@leuenberger.net
- Update to 1.0.0-rc4
  Notable fixes:
  - Mac OS crashes
  - Qt Fullscreen controllers
  - libass, playlist and skins crashes
  - dv update to new API
  - TrueHD in M2TS
- dropped vlc-xulrunner191 patch; it was merged upstream
* Sat May 30 2009 dominique-vlc.suse@leuenberger.net
- Add vlc-xulrunner191 patch (conditional. Works only with xul 191)
